export default ellipsoid;
export type EllipsoidOptions = {
    radius?: number;
    nx?: number;
    ny?: number;
    rx?: number;
    ry?: number;
    rz?: number;
    theta?: number;
    thetaOffset?: number;
    phi?: number;
    phiOffset?: number;
};
/**
 * @typedef {object} EllipsoidOptions
 * @property {number} [radius=0.5]
 * @property {number} [nx=32]
 * @property {number} [ny=16]
 * @property {number} [rx=1]
 * @property {number} [ry=0.5]
 * @property {number} [rz=ry]
 * @property {number} [theta=Math.PI]
 * @property {number} [thetaOffset=0]
 * @property {number} [phi=TAU]
 * @property {number} [phiOffset=0]
 */
/**
 * Default to an oblate spheroid.
 * @alias module:ellipsoid
 * @param {EllipsoidOptions} [options={}]
 * @returns {import("../types.js").SimplicialComplex}
 */
declare function ellipsoid({ radius, nx, ny, rx, ry, rz, theta, thetaOffset, phi, phiOffset, }?: EllipsoidOptions, ...args: any[]): import("../types.js").SimplicialComplex;
