export default squircle;
export type SquircleOptions = {
    sx?: number;
    sy?: number;
    radius?: number;
    segments?: number;
    innerSegments?: number;
    theta?: number;
    thetaOffset?: number;
    mapping?: Function;
    /**
     * Squareness (0 < s <= 1)
     */
    squareness?: number;
};
/**
 * @typedef {object} SquircleOptions
 * @property {number} [sx=1]
 * @property {number} [sy=1]
 * @property {number} [radius=0.5]
 * @property {number} [segments=128]
 * @property {number} [innerSegments=16]
 * @property {number} [theta=TAU]
 * @property {number} [thetaOffset=0]
 * @property {Function} [mapping=mappings.fgSquircular]
 * @property {number} [squareness=0.95] Squareness (0 < s <= 1)
 */
/**
 * Fernández-Guasti squircle
 * @see [Squircular Calculations – Chamberlain Fong]{@link https://arxiv.org/vc/arxiv/papers/1604/1604.02174v1.pdf}
 *
 * @alias module:squircle
 * @param {SquircleOptions} [options={}]
 * @returns {import("../types.js").SimplicialComplex}
 */
declare function squircle({ sx, sy, radius, segments, innerSegments, theta, thetaOffset, mapping, squareness, }?: SquircleOptions, ...args: any[]): import("../types.js").SimplicialComplex;
